@@ -56,7 +56,7 @@ test_that("tidy, glance, summary, and print work", {
 
   expect_equal(
     colnames(glance(lmo)),
-    c("r.squared", "adj.r.squared", "statistic", "p.value", "df.residual", "N", "se_type")
+    c("r.squared", "adj.r.squared", "statistic", "p.value", "df.residual", "nobs", "se_type")
   )
 
   expect_equal(
@@ -179,7 +179,7 @@ test_that("tidy, glance, summary, and print work", {
 
   expect_equal(
     colnames(glance(lmlo)),
-    c("r.squared", "adj.r.squared", "statistic", "p.value", "df.residual", "N", "se_type")
+    c("r.squared", "adj.r.squared", "statistic", "p.value", "df.residual", "nobs", "se_type")
   )
 
   ## lh_robust
@@ -262,7 +262,7 @@ test_that("tidy, glance, summary, and print work", {
 
   expect_equal(
     colnames(glance(ht)),
-    c("N", "se_type", "condition2", "condition1")
+    c("nobs", "se_type", "condition2", "condition1")
   )
 
   ## difference_in_means
@@ -290,7 +290,7 @@ test_that("tidy, glance, summary, and print work", {
 
   expect_equal(
     colnames(glance(dim)),
-    c("design", "df", "N", "N_blocks", "N_clusters", "condition2", "condition1")
+    c("design", "df", "nobs", "nblocks", "nclusters", "condition2", "condition1")
   )
 
   # rank deficient
@@ -345,15 +345,16 @@ test_that("vcov works", {
     "return_vcov = TRUE"
   )
 
-  expect_error(
-    vcov(horvitz_thompson(y ~ x, condition_prs = p, data = dat)),
-    "supported|horvitz_thompson"
+  hto <- horvitz_thompson(y ~ x, condition_prs = p, data = dat)
+  expect_equal(
+    vcov(hto),
+    matrix(hto$std.error ^ 2, dimnames = list(hto$term, hto$term))
   )
 
-
-  expect_error(
-    vcov(difference_in_means(y ~ x, data = dat)),
-    "supported|difference_in_means"
+  dimo <- difference_in_means(y ~ x, data = dat)
+  expect_equal(
+    vcov(dimo),
+    matrix(dimo$std.error ^ 2, dimnames = list(dimo$term, dimo$term))
   )
 
   # Instrumental variables
@@ -989,3 +990,55 @@ test_that("predict.iv_robust works with fixed effects", {
   )
 
 })
+
+test_that("tidy conf_level", {
+
+    mod <- lm_robust(mpg ~ hp + factor(cyl) + gear, mtcars)
+
+    expect_equal(unname(confint(mod, level = .95)[, 1]),
+                 tidy(mod)$conf.low)
+
+    expect_equal(unname(confint(mod, level = .999)[, 1]),
+                 tidy(mod, conf.int = TRUE, conf.level = .999)$conf.low)
+
+    dimmod <- difference_in_means(mpg ~ am, mtcars)
+
+    expect_equal(
+      unname(confint(dimmod, level = .999)[, 1]),
+      tidy(dimmod, conf.int = TRUE, conf.level = .999)$conf.low
+    )
+
+    expect_false(
+      tidy(dimmod, conf.int = TRUE, conf.level = .999)$conf.low == tidy(dimmod)$conf.low
+    )
+
+    htmod <- horvitz_thompson(mpg ~ am, mtcars, condition_prs = 0.5)
+
+    expect_equal(
+      unname(confint(htmod, level = .999)[, 1]),
+      tidy(htmod, conf.int = TRUE, conf.level = .999)$conf.low
+    )
+
+    expect_false(
+      tidy(htmod, conf.int = TRUE, conf.level = .999)$conf.low == tidy(htmod)$conf.low
+    )
+
+})
+
+
+test_that("update works", {
+  l1 <- lm_robust(mpg ~ hp, mtcars)
+  l2 <- lm_robust(mpg ~ cyl, mtcars)
+  expect_equal(
+    tidy(l2),
+    tidy(update(l1, . ~ cyl))
+  )
+
+  iv1 <- iv_robust(mpg ~ hp | am, mtcars)
+  iv2 <- iv_robust(mpg ~ cyl | am, mtcars)
+  expect_equal(
+    tidy(iv2),
+    tidy(update(iv1, . ~ cyl | .))
+  )
+
+})
